@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-config.h.in,v 1.25 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-config.h.in,v 1.27 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -33,12 +33,12 @@
 
 /* Define some version variables */
 #define XMEDCON_MAJOR    "0"
-#define XMEDCON_MINOR    "13"
-#define XMEDCON_MICRO    "0"
+#define XMEDCON_MINOR    "14"
+#define XMEDCON_MICRO    "1"
 #define XMEDCON_PRGR     "(X)MedCon"
-#define XMEDCON_DATE     "23-jun-2013"
-#define XMEDCON_VERSION  "0.13.0"
-#define XMEDCON_LIBVERS  "(X)MedCon 0.13.0 by Erik Nolf"
+#define XMEDCON_DATE     "26-dec-2015"
+#define XMEDCON_VERSION  "0.14.1"
+#define XMEDCON_LIBVERS  "(X)MedCon 0.14.1 by Erik Nolf"
 
 /* Define if format enabled */
 #define MDC_INCLUDE_ACR   1
@@ -54,7 +54,7 @@
 #define MDC_INCLUDE_TPC   1    /* TPC ecat7 write */
 
 /* Define some machine dependencies */
-#define MDC_WORDS_BIGENDIAN  1
+#define MDC_WORDS_BIGENDIAN  0
 #define MDC_SIZEOF_SHORT     2
 #define MDC_SIZEOF_INT       4
 #define MDC_SIZEOF_LONG      4
